import matplotlib.pyplot as plt
import numpy as np
import pandas as pd
from pathlib import Path


def infos_from_calibration_log(result_path: Path,
                               used_error_type='RMSE',
                               log_lines: str = None,
                               save_path: Path = None):
    plot_strings = []

    if log_lines is not None:
        lines = log_lines
    else:
        with open(result_path / 'Calibrator.log', 'r') as f:
            lines = f.readlines()
            
    for idx, line in enumerate(reversed(lines)):
        if line.find('Start calibration') != -1:
            break
    lines = lines[-(idx+1):]


    best_line = (np.inf, None)

    n_failed = 0
    n_sucess = 0
    scores = []
    timestamps = []
    for line in lines:
        start_ix = line.find('Start calibration')
        if start_ix != -1:
            start_timestamp = line[:line.find('INFO')].strip()
            start_timestamp = pd.to_datetime(start_timestamp,
                                             format='%d.%m.%Y-%H:%M:%S')
            print(start_timestamp)
        ix = line.find('*')
        if ix == -1:
            if 'Simulation failed' in line:
                n_failed += 1
            continue
        if "INFO" not in line:
            continue
        n_sucess += 1
        points = line.split()
        equal_sign = points.index("=")
        score_index = equal_sign - 2
        score = float(points[score_index])
        scores.append(score)

        timestamp = line[:line.find('INFO')].strip()

        timestamp = pd.to_datetime(timestamp,
                                   format='%d.%m.%Y-%H:%M:%S')

        timestamps.append(timestamp)
        if score < best_line[0]:
            best_line = (score, line, timestamp)
    string1 = f'Number of sucessful simulations: {n_sucess}'
    plot_strings.append(string1)
    print(string1)
    # print(f'Number of succesful simulations: {n_sucess}')
    if used_error_type == 'RMSE':
        string2 = f'Best {used_error_type}: {best_line[0]}'
    else:
        string2 = f'Best {used_error_type}: {best_line[0]*100}%'
    plot_strings.append(string2)
    print(string2)

    string3 = f'Time for calibration until best result: {best_line[-1] - start_timestamp}'
    plot_strings.append(string3)
    print(string3)
    
    for n in range(len(scores)):
        score = scores[n]
        if score <= 1.1 * best_line[0]:
            string4 = f'Time for calibration until best result +10%: {timestamps[n] - start_timestamp}'
            plot_strings.append(string4)
            print(string4)
            break
        
    use_line = best_line[1]
    start = use_line.find('Calibrator:')
    if 'e-' in use_line:
        use_line = use_line[:use_line.find('e-')]

    stop = use_line.rfind('-')
    params = use_line[start + 11: stop].split()
    params = [float(i) for i in params][1:-1]

    default_colors = plt.rcParams['axes.prop_cycle'].by_key()['color']
    x = np.arange(len(scores))
    x_conv = [x[0]]
    scores_conv = [scores[0]]

    for n in range(1, x.shape[0]):
        if scores[n] < scores_conv[-1]:
            scores_conv.append(scores[n])
            x_conv.append(x[n])

    plt.figure(figsize=(16, 9))
    if used_error_type != 'RMSE':
        scores = np.array(scores)
        scores_conv = np.array(scores_conv)
        scores *= 100
        scores_conv *= 100
    plt.scatter(x, scores, label='all results')
    plt.plot(x_conv, scores_conv, c=default_colors[1])
    plt.xlabel('Number of successful iterations')
    if used_error_type != 'RMSE':
        plt.ylabel(f'{used_error_type} in %')
    else:
        plt.ylabel('RMSE')
    plt.scatter(x_conv, scores_conv, label='converging results')
    plt.legend()
    
    total_string = '\n'.join(plot_strings)
    plt.figtext(0.125, -0.02, total_string)
    if save_path is not None:
        plt.savefig(save_path, bbox_inches='tight')
    else:
        plt.show()
    print("")