from pathlib import Path
from energyplus_calibrator.energy_plus_api import EnergyPlusAPI
import json


def main():
    CD = Path(__file__).parents[1] / 'results' / 'e1_result'
    MODEL_PATH = Path(__file__).parents[0] / \
        'data' / 'ExampleHOM_BESMod_Density_V2310.idf'
    WEATHER_PATH = Path(__file__).parents[0] / 'data' / 'Potsdam_TRY2015.epw'
    ENERGYPLUS_VERSION = "23.1"

    simulation_setup = {"sim_intervals": [
        '2015-01-01 to 2015-02-01'
    ],
        "evaluation_intervals": [
        '2015-01-01 to 2015-02-01'
    ],
        "dataframe_interval": "Hourly"}

    parameters = {
        "ZoneInfiltration:DesignFlowRate/BGVPLnC4OUeqffvCvT6TTQ/air_changes_per_hour": 0.4}

    EP_API = EnergyPlusAPI(
        cd=CD,
        override_cd=True,
        model_path=MODEL_PATH,
        epw_filepath=WEATHER_PATH,
        energyplus_install_dir=Path('D:\Programme\EnergyPlus'),
        energyplus_version=ENERGYPLUS_VERSION,
        n_cpu=1
    )

    EP_API.set_sim_setup(sim_setup=simulation_setup)

    dfs = EP_API.simulate(
        parameters=parameters,
        return_option="time_series"
    )

    dfs.to_csv(EP_API.cd / 'output.csv')

    with open(EP_API.cd / 'cols.json', 'w') as f:
        json.dump(list(dfs), f)


if __name__ == "__main__":
    main()
