from data.calibration_config import (
    CD,
    MODEL_PATH,
    WEATHER_PATH,
    SIMULATION_SETUP,
    TUNER_PARAMS,
    GOALS,
    ENERGYPLUS_INSTALL_DIR,
    ENERGYPLUS_VERSION,
    GOAL_VAR_CONVERT_DICT,
    N_CPU,
    FRAMEWORK,
    METHOD,
    MAX_TIME)

from energyplus_calibrator.calibration_class import EnergyPlusCalibrator
from pathlib import Path
import pandas as pd


def main():
    measurement_data = pd.read_csv(
        Path(__file__).parents[0] / 'data' / 'measurement_data.csv')
    measurement_data.set_index('Date/Time', inplace=True)
    measurement_data.index = pd.to_datetime(measurement_data.index)

    calibrator = EnergyPlusCalibrator(cd=CD,
                                      model_path=MODEL_PATH,
                                      epw_file_path=WEATHER_PATH,
                                      energyplus_install_dir=ENERGYPLUS_INSTALL_DIR,
                                      energyplus_version=ENERGYPLUS_VERSION,
                                      simulation_setup=SIMULATION_SETUP,
                                      tuner_paras=TUNER_PARAMS,
                                      goals=GOALS,
                                      real_data_dataframe=measurement_data,
                                      goal_var_convert_dict=GOAL_VAR_CONVERT_DICT,
                                      n_cpu=N_CPU)

    calibrator.calibrate(framework=FRAMEWORK,
                         method=METHOD,
                         max_time=MAX_TIME)


if __name__ == '__main__':
    main()
